pub fn parse_and_validate(input: &str) -> Result<Item, ParseError>Expand description
Parse and validate a PLN layout string.
This runs both parsing and semantic validation (e.g. checking that col/row units are used in the correct split direction).
pub fn parse_and_validate(input: &str) -> Result<Item, ParseError>Parse and validate a PLN layout string.
This runs both parsing and semantic validation (e.g. checking that col/row units are used in the correct split direction).